@@ -32,7 +32,7 @@ Here is a minimal deployable pattern definition:
 
 Typescript
 
-```typescript
+```python
 import { Construct } from 'constructs';
 import { Stack, StackProps } from 'aws-cdk-lib';
 import { LambdaToSsmstringparameterProps,  LambdaToSsmstringparameter } from '@aws-solutions-constructs/aws-lambda-ssmstringparameter';
@@ -159,6 +159,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_ec2
@@ -185,11 +187,11 @@ class LambdaToSsmstringparameter(
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_string_parameter_obj: typing.Optional[aws_cdk.aws_ssm.StringParameter] = None,
         existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
+        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
         string_parameter_environment_variable_name: typing.Optional[builtins.str] = None,
         string_parameter_permissions: typing.Optional[builtins.str] = None,
-        string_parameter_props: typing.Optional[aws_cdk.aws_ssm.StringParameterProps] = None,
-        vpc_props: typing.Optional[aws_cdk.aws_ec2.VpcProps] = None,
+        string_parameter_props: typing.Optional[typing.Union[aws_cdk.aws_ssm.StringParameterProps, typing.Dict[str, typing.Any]]] = None,
+        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -208,6 +210,10 @@ class LambdaToSsmstringparameter(
         :since: 1.49.0
         :summary: Constructs a new instance of the LambdaToSsmstringparameter class.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(LambdaToSsmstringparameter.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = LambdaToSsmstringparameterProps(
             deploy_vpc=deploy_vpc,
             existing_lambda_obj=existing_lambda_obj,
@@ -261,11 +267,11 @@ class LambdaToSsmstringparameterProps:
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_string_parameter_obj: typing.Optional[aws_cdk.aws_ssm.StringParameter] = None,
         existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
+        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
         string_parameter_environment_variable_name: typing.Optional[builtins.str] = None,
         string_parameter_permissions: typing.Optional[builtins.str] = None,
-        string_parameter_props: typing.Optional[aws_cdk.aws_ssm.StringParameterProps] = None,
-        vpc_props: typing.Optional[aws_cdk.aws_ec2.VpcProps] = None,
+        string_parameter_props: typing.Optional[typing.Union[aws_cdk.aws_ssm.StringParameterProps, typing.Dict[str, typing.Any]]] = None,
+        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param deploy_vpc: Whether to deploy a new VPC. Default: - false
@@ -286,6 +292,17 @@ class LambdaToSsmstringparameterProps:
             string_parameter_props = aws_cdk.aws_ssm.StringParameterProps(**string_parameter_props)
         if isinstance(vpc_props, dict):
             vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
+        if __debug__:
+            type_hints = typing.get_type_hints(LambdaToSsmstringparameterProps.__init__)
+            check_type(argname="argument deploy_vpc", value=deploy_vpc, expected_type=type_hints["deploy_vpc"])
+            check_type(argname="argument existing_lambda_obj", value=existing_lambda_obj, expected_type=type_hints["existing_lambda_obj"])
+            check_type(argname="argument existing_string_parameter_obj", value=existing_string_parameter_obj, expected_type=type_hints["existing_string_parameter_obj"])
+            check_type(argname="argument existing_vpc", value=existing_vpc, expected_type=type_hints["existing_vpc"])
+            check_type(argname="argument lambda_function_props", value=lambda_function_props, expected_type=type_hints["lambda_function_props"])
+            check_type(argname="argument string_parameter_environment_variable_name", value=string_parameter_environment_variable_name, expected_type=type_hints["string_parameter_environment_variable_name"])
+            check_type(argname="argument string_parameter_permissions", value=string_parameter_permissions, expected_type=type_hints["string_parameter_permissions"])
+            check_type(argname="argument string_parameter_props", value=string_parameter_props, expected_type=type_hints["string_parameter_props"])
+            check_type(argname="argument vpc_props", value=vpc_props, expected_type=type_hints["vpc_props"])
         self._values: typing.Dict[str, typing.Any] = {}
         if deploy_vpc is not None:
             self._values["deploy_vpc"] = deploy_vpc
